@@ -1,5 +1,5 @@
 my $title = translate('editTranslation');
-print '<div class="ShowTables" style="margin-top:1.65em">';
+print '<div class="ShowTables marginTop">';
 
 loadTranslate($m_hrSettings->{translate});
 *m_hrLng = \$MySQL::Admin::Translate::lang;
@@ -8,9 +8,11 @@ foreach my $key (sort keys %{$m_hrLng}) {
     push @l, $key;
 }
 my $txt = translate('translate');
-print start_form(-method => "POST",
-                          -onSubmit => "submitForm(this,'$m_sAction','$txt');return false;",
-                          -action => $ENV{SCRIPT_NAME})
+print start_form(
+                 -method   => "POST",
+                 -onSubmit => "submitForm(this,'showaddTranslation','$txt');return false;",
+                 -action   => "$m_hrSettings->{cgi}{serverName}$ENV{SCRIPT_NAME}"
+                )
   . hidden({-name => 'action'}, 'showaddTranslation')
   . hidden(
            {
@@ -18,7 +20,7 @@ print start_form(-method => "POST",
             -default => '1'
            },
            'true'
-  )
+          )
   . table(
           {
            -align  => 'center',
@@ -39,9 +41,9 @@ print start_form(-method => "POST",
                              -name  => 'key'
                             },
                             'name'
-                  )
-              )
-          ),
+                           )
+                )
+            ),
           Tr(
               {
                -align  => 'left',
@@ -55,9 +57,9 @@ print start_form(-method => "POST",
                              -name  => 'txt'
                             },
                             'txt'
-                  )
-              )
-          ),
+                           )
+                )
+            ),
           Tr(
               {
                -align  => 'left',
@@ -70,17 +72,18 @@ print start_form(-method => "POST",
                              -name     => 'lang',
                              -values   => [@l],
                              -style    => "width:100%"
-                  ),
-              )
-          ),
+                            ),
+                )
+            ),
           Tr(
               {
                -align  => 'right',
                -valign => 'top'
               },
               td({colspan => 2}, submit(-value => 'Add Translation'))
-          )
-  ) . end_form;
+            )
+         )
+  . end_form;
 if (param('do')) {
     my $key = param('key');
     my $txt = param('txt');
