@@ -1,57 +1,56 @@
 $VAR1 = {
-          'floodtime' => 10,
-          'admin' => {
-                       'password' => 'testpass'
-                     },
-          'language' => 'en',
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
-          'scriptAlias' => 'cgi-bin',
-          'tree' => {
-                      'links' => '/var/www/cgi-bin/config/links.pl',
-                      'navigation' => '/var/www/cgi-bin/config/tree.pl'
-                    },
-          'mod' => 'n',
-          'database' => {
-                          'CurrentHost' => 'localhost',
-                          'host' => 'localhost',
-                          'name' => 'LZE',
-                          'CurrentPass' => '',
-                          'password' => '',
-                          'CurrentUser' => 'root',
-                          'CurrentDb' => 'LZE',
-                          'user' => 'root'
-                        },
           'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'cgi' => {
-                     'style' => 'mysql',
-                     'title' => 'MySQL::Admin',
-                     'DocumentRoot' => '/var/www/htdocs',
-                     'serverName' => 'localhost',
-                     'alias' => 'cgi-bin',
-                     'expires' => '+1y',
-                     'bin' => '/var/www/cgi-bin',
-                     'cookiePath' => '/'
-                   },
-          'version' => '0.92',
           'uploads' => {
                          'path' => '/var/www/htdocs//download',
-                         'chmod' => 438,
-                         'maxlength' => 21000000
+                         'maxlength' => '2100000000000000',
+                         'chmod' => 438
                        },
-          'files' => {
-                       'chmod' => '0755',
-                       'group' => 'lze',
-                       'owner' => 'lze'
-                     },
+          'cgi' => {
+                     'cookiePath' => '/',
+                     'serverName' => 'http://localhost',
+                     'expires' => '+1y',
+                     'DocumentRoot' => '/var/www/htdocs/',
+                     'style' => 'mysql',
+                     'bin' => '/var/www/cgi-bin',
+                     'title' => 'MySQL::Admin'
+                   },
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'floodtime' => 10,
+          'defaultAction' => 'ShowDatabases',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'version' => '0.93',
+          'database' => {
+                          'name' => 'MySQLAdmin',
+                          'CurrentUser' => 'root',
+                          'CurrentDb' => 'MySQLAdmin',
+                          'user' => 'root',
+                          'CurrentHost' => 'localhost',
+                          'password' => '',
+                          'host' => 'localhost',
+                          'CurrentPass' => ''
+                        },
           'session' => '/var/www/cgi-bin/config/session.pl',
           'news' => {
                       'captcha' => 3,
-                      'maxlength' => '2000',
                       'right' => 5,
                       'messages' => '5'
                     },
-          'defaultAction' => 'ShowDatabases',
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'translate' => '/var/www/cgi-bin/config/translate.pl'
+          'htmlright' => '2',
+          'tree' => {
+                      'navigation' => '/var/www/cgi-bin/config/tree.pl',
+                      'links' => '/var/www/cgi-bin/config/links.pl'
+                    },
+          'files' => {
+                       'owner' => 'lze',
+                       'chmod' => '0755',
+                       'group' => 'lze'
+                     },
+          'size' => '16',
+          'admin' => {
+                       'password' => 'testpass'
+                     },
+          'mod' => 'n',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'language' => 'en'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
