@@ -6,20 +6,19 @@ my $cwd  = cwd();
 my $test = new HTML::Menu::Pages;
 use MySQL::Admin qw(:all);
 print header;
-print start_html(-title => 'HTML::Menu::Pages', -style => 'style/lze/pages.css',);
+print start_html(-title => 'HTML::Menu::Pages',
+                 -style => 'style/lze/pages.css',);
 my %needed = (
 
-        length => '345',
+    length => '345',
 
-        style => 'lze',
+    style => 'lze',
 
-        mod_rewrite => 0,
+    action => "Pages",
 
-        action => "Pages",
+    start => param('von') ? param('von') : 0,
 
-        start => param('von') ? param('von') : 0,
-
-        path => "../",
+    path => "../",
 
 );
 print $test->makePages(\%needed);
