@@ -1,28 +1,27 @@
 package DBI::Library;
 use strict;
-use warnings FATAL => 'all';
-no warnings 'redefine';
+use warnings;
 use utf8;
-use vars qw( 
-$m_dbh 
-$m_dsn 
-$m_sDefaultClass 
-$m_hrSettings  
-@EXPORT_OK 
-@ISA 
-%m_hFunctions 
-$m_sStyle 
-$m_nRight 
-$m_tbl 
-$driver 
-$m_oDatabase 
-$m_sHost 
-$m_sPass 
-$m_sUser
-);
+use vars qw(
+  $m_dbh
+  $m_dsn
+  $m_sDefaultClass
+  $m_hrSettings
+  @EXPORT_OK
+  @ISA
+  %m_hFunctions
+  $m_sStyle
+  $m_nRight
+  $m_tbl
+  $driver
+  $m_oDatabase
+  $m_sHost
+  $m_sPass
+  $m_sUser
+  );
 $m_sDefaultClass = 'DBI::Library' unless defined $DBI::Library::m_sDefaultClass;
-@DBI::Library::EXPORT_OK
-    = qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver  useexecute quote quote_identifier void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists initDB $m_dsn $m_dbh selectTable);
+@DBI::Library::EXPORT_OK =
+  qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver  useexecute quote quote_identifier void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists initDB $m_dsn $m_dbh selectTable);
 %DBI::Library::EXPORT_TAGS = (
     'all' => [
         qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver useexecute quote quote_identifier void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists initDB selectTable)
@@ -34,7 +33,7 @@ $m_sDefaultClass = 'DBI::Library' unless defined $DBI::Library::m_sDefaultClass;
         qw(quote quote_identifier CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute selectTable)
     ],
 );
-$DBI::Library::VERSION = '0.92';
+$DBI::Library::VERSION = '0.93';
 $m_tbl                 = 'querys';
 $driver                = 'mysql';
 require Exporter;
@@ -133,12 +132,12 @@ DBI::Library is a DBI subclass providing a dynamic SQL Libary.
 =cut
 
 sub new {
-    my ( $class, @initializer ) = @_;
+    my ($class, @initializer) = @_;
     my $self = {};
     my $m_dbh;
     bless $self, ref $class || $class || $m_sDefaultClass;
-    $m_dbh = $self->initDB(@initializer) if(@initializer);
-    return ( $self, $m_dbh ) if $m_dbh;
+    $m_dbh = $self->initDB(@initializer) if (@initializer);
+    return ($self, $m_dbh) if $m_dbh;
     return $self;
 }
 
@@ -162,27 +161,30 @@ sub new {
 =cut
 
 sub initDB {
-    my ( $self, @p ) = getSelf(@_);
+    my ($self, @p) = getSelf(@_);
     my $hash = $p[0];
-    $m_oDatabase
-        = defined $hash->{name}
-        ? $hash->{name}
-        : 'LZE';    #todo durch make setzen
-    $m_sHost    = defined $hash->{host}     ? $hash->{host}     : 'localhost';
+    $m_oDatabase =
+      defined $hash->{name}
+      ? $hash->{name}
+      : '%DATABASE%';
+    $m_sHost = defined $hash->{host}     ? $hash->{host}     : 'localhost';
     $m_sUser = defined $hash->{user}     ? $hash->{user}     : 'root';
-    $m_sPass    = defined $hash->{password} ? $hash->{password} : '';
+    $m_sPass = defined $hash->{password} ? $hash->{password} : '';
     my $install = defined $hash->{install} ? $hash->{install} : 0;
-    $m_sStyle = defined $hash->{style} ? $hash->{style} : 'lze';
-    $m_dsn      = "DBI:$driver:database=$m_oDatabase;host=$m_sHost";
-    $m_dbh    = DBI::Library->connect(
+    $m_sStyle = defined $hash->{style} ? $hash->{style} : 'mysql';
+    $m_dsn = "DBI:$driver:database=$m_oDatabase;host=$m_sHost";
+    $m_dbh = DBI::Library->connect(
         $m_dsn, $m_sUser, $m_sPass,
-        {   RaiseError => 1,
-            PrintError => 0,
-            AutoCommit => 1,
+        {
+         RaiseError => 1,
+         PrintError => 0,
+         AutoCommit => 1,
+         #mysql_enable_utf8 => 1
         }
-        ) or warn "$DBI::Library::errs";
-        $self->void("SET NAMES 'utf8_general_ci'");
-    if( !$install && $m_oDatabase eq 'LZE' ) {
+      )
+      or warn "$DBI::Library::errs";
+    $self->void("SET NAMES 'utf8_general_ci'");
+    if (!$install && $m_oDatabase eq '%DATABASE%') {
         my @q = $self->fetch_array('select title from querys');
         $m_hFunctions{$_} = $_ foreach (@q);
     }
@@ -200,7 +202,7 @@ default: Mysql
 =cut
 
 sub Driver {
-    if( $_[0] ) {
+    if ($_[0]) {
         $driver = $_[0];
     } else {
         return $driver;
@@ -256,11 +258,11 @@ $bool =  $database->tableExists($table);
 =cut
 
 sub tableExists {
-    my ( $self, @p ) = getSelf(@_);
-    my $table     = $m_dbh->quote( $p[0] );
+    my ($self, @p) = getSelf(@_);
+    my $table     = $m_dbh->quote($p[0]);
     my $db_clause = '';
-    ( $db_clause, $table ) = ( " FROM $1", $2 ) if $table =~ /(.*)\.(.*)/;
-    return ( $m_dbh->selectrow_array("SHOW TABLES $db_clause LIKE $table") );
+    ($db_clause, $table) = (" FROM $1", $2) if $table =~ /(.*)\.(.*)/;
+    return ($m_dbh->selectrow_array("SHOW TABLES $db_clause LIKE $table"));
 }
 
 =head2 tableLength
@@ -270,10 +272,10 @@ $length  = $database->tableLength($table);
 =cut
 
 sub tableLength {
-    my ( $self, @p ) = getSelf(@_);
-    my $table = $m_dbh->quote_identifier( $p[0] );
+    my ($self, @p) = getSelf(@_);
+    my $table = $m_dbh->quote_identifier($p[0]);
     my $sql   = "select count(*) from $table";
-    if( $self->tableExists( $p[0] ) ) {
+    if ($self->tableExists($p[0])) {
         my $sth = $m_dbh->prepare($sql) or warn $m_dbh->errstr;
         $sth->execute() or warn $m_dbh->errstr;
         my $length = $sth->fetchrow_array;
@@ -313,18 +315,18 @@ Fo Syntax:
 =cut
 
 sub addexecute {
-    my ( $self, @p ) = getSelf(@_);
+    my ($self, @p) = getSelf(@_);
     my $hash        = $p[0];
-    my $m_sTitle    = ( ( defined $hash->{title} ) ) ? $hash->{title} : 0;
-    my $sql         = $hash->{sql} if( ( defined $hash->{sql} ) );
-    my $description = $hash->{description} if( defined $hash->{description} );
-    my $return      = $hash->{'return'} if( defined $hash->{'return'} );
-    unless ( $m_hFunctions{$m_sTitle} ) {
-        my $sql_addexecute
-            = qq/INSERT INTO querys(`title`,`sql`,`description`,`return`) VALUES(?,?,?,?);/;
+    my $m_sTitle    = ((defined $hash->{title})) ? $hash->{title} : 0;
+    my $sql         = $hash->{sql} if ((defined $hash->{sql}));
+    my $description = $hash->{description} if (defined $hash->{description});
+    my $return      = $hash->{'return'} if (defined $hash->{'return'});
+    unless ($m_hFunctions{$m_sTitle}) {
+        my $sql_addexecute =
+          qq/INSERT INTO querys(`title`,`sql`,`description`,`return`) VALUES(?,?,?,?);/;
         my $sth = $m_dbh->prepare($sql_addexecute);
-        $sth->execute( $m_sTitle, $sql, $description, $return )
-            or warn $m_dbh->errstr;
+        $sth->execute($m_sTitle, $sql, $description, $return)
+          or warn $m_dbh->errstr;
         $sth->finish();
         $self->updateModules();
     } else {
@@ -353,21 +355,21 @@ sub addexecute {
 =cut
 
 sub editexecute {
-    my ( $self, @p ) = getSelf(@_);
+    my ($self, @p) = getSelf(@_);
     my $hash = $p[0];
-    my $m_sTitle = ( ( defined $hash->{title} ) ) ? $hash->{title} : 0;
-    my $newTitle
-        = ( ( defined $hash->{newTitle} ) ) ? $hash->{newTitle} : $m_sTitle;
-    my $sql = $hash->{sql} if( ( defined $hash->{sql} ) );
-    my $description = $hash->{description} if( defined $hash->{description} );
-    my $return = ( defined $hash->{'return'} ) ? $hash->{'return'} : 'array';
+    my $m_sTitle = ((defined $hash->{title})) ? $hash->{title} : 0;
+    my $newTitle =
+      ((defined $hash->{newTitle})) ? $hash->{newTitle} : $m_sTitle;
+    my $sql         = $hash->{sql}         if ((defined $hash->{sql}));
+    my $description = $hash->{description} if (defined $hash->{description});
+    my $return = (defined $hash->{'return'}) ? $hash->{'return'} : 'array';
 
-    if( $m_hFunctions{$m_sTitle} ) {
-        my $sql_edit
-            = qq(update querys set title = ?, sql=? ,description=?,return=? where title = ? );
+    if ($m_hFunctions{$m_sTitle}) {
+        my $sql_edit =
+          qq(update querys set title = ?, sql=? ,description=?,return=? where title = ? );
         my $sth = $m_dbh->prepare($sql_edit);
-        $sth->execute( $newTitle, $sql, $description, $return, $m_sTitle )
-            or warn $m_dbh->errstr;
+        $sth->execute($newTitle, $sql, $description, $return, $m_sTitle)
+          or warn $m_dbh->errstr;
         $sth->finish();
 
     } else {
@@ -400,18 +402,17 @@ example:
 =cut
 
 sub useexecute {
-    my ( $self, @p ) = getSelf(@_);
+    my ($self, @p) = getSelf(@_);
     my $m_sTitle = shift(@p);
     my $sql      = 'select `sql`,`return` from querys where `title` = ?';
     my $sth      = $m_dbh->prepare($sql);
     $sth->execute($m_sTitle) or warn $m_dbh->errstr;
-    my ( $sqlexec, $return ) = $sth->fetchrow_array();
+    my ($sqlexec, $return) = $sth->fetchrow_array();
     $sqlexec =~ s/<TABLE>/$m_tbl/g;
-    if( ref $p[0] eq 'HASH' ) {
+    if (ref $p[0] eq 'HASH') {
         my $ref = shift(@p);
-        foreach my $key ( keys %{ $ref->{identifier} } ) {
-            $sqlexec
-                =~ s/table_$key/$m_dbh->quote_identifier($ref->{identifier}{$key})/ge;
+        foreach my $key (keys %{$ref->{identifier}}) {
+            $sqlexec =~ s/table_$key/$m_dbh->quote_identifier($ref->{identifier}{$key})/ge;
         }
     }
     $sth->finish();
@@ -425,7 +426,7 @@ sub useexecute {
 =cut
 
 sub deleteexecute {
-    my ( $self, @p ) = getSelf(@_);
+    my ($self, @p) = getSelf(@_);
     my $id         = $p[0];
     my $sql_delete = 'DELETE FROM querys Where title  = ?';
     my $sth        = $m_dbh->prepare($sql_delete);
@@ -440,10 +441,10 @@ sub deleteexecute {
 =cut
 
 sub fetch_array {
-    my ( $self, @p ) = getSelf(@_);
+    my ($self, @p) = getSelf(@_);
     my $sql = shift @p;
     my @r;
-    eval( '
+    eval('
 my $sth = $m_dbh->prepare($sql);
 if(defined $p[0]) {
 $sth->execute(@p) or warn $m_dbh->errstr;
@@ -453,7 +454,7 @@ $sth->execute() or warn $m_dbh->errstr;
 while(my @comms = $sth->fetchrow_array()) {
 push(@r, @comms);
 }
-$sth->finish();' );
+$sth->finish();');
     @r = $@ if $@;
     return @r;
 }
@@ -465,10 +466,10 @@ $sth->finish();' );
 =cut
 
 sub fetch_AoH {
-    my ( $self, @p ) = getSelf(@_);
+    my ($self, @p) = getSelf(@_);
     my $sql = shift @p;
     my @r;
-    eval( '
+    eval('
 my $sth = $m_dbh->prepare($sql);
 if(defined $p[0]) {
 $sth->execute(@p) or warn $m_dbh->errstr;
@@ -478,7 +479,7 @@ $sth->execute() or warn $m_dbh->errstr;
 while(my $h = $sth->fetchrow_hashref) {
 push(@r, $h);
 }
-$sth->finish();' );
+$sth->finish();');
     @r = $@ if $@;
     return @r;
 }
@@ -490,10 +491,10 @@ $hashref = $database->fetch_hashref($sql)
 =cut
 
 sub fetch_hashref {
-    my ( $self, @p ) = getSelf(@_);
+    my ($self, @p) = getSelf(@_);
     my $sql = shift @p;
     my $h;
-    eval( '
+    eval('
 my $sth = $m_dbh->prepare($sql);
 if(defined $p[0]) {
 $sth->execute(@p) or warn $m_dbh->errstr;
@@ -502,7 +503,7 @@ $sth->execute() or warn $m_dbh->errstr;
 }
 $h = $sth->fetchrow_hashref();
 $sth->finish();
-' );
+');
     $h = "$@" if $@;
     return $h;
 }
@@ -514,15 +515,15 @@ void(sql)
 =cut
 
 sub void {
-    my ( $self, @p ) = getSelf(@_);
+    my ($self, @p) = getSelf(@_);
     my $sql = shift @p;
     my $sth = $m_dbh->prepare($sql);
-    eval( '
+    eval('
 if(defined $p[0]) {
 $sth->execute(@p) or warn $m_dbh->errstr;
 } else {
 $sth->execute() or warn $m_dbh->errstr;
-}' );
+}');
     $sth->finish();
     return "$@" if $@;
 }
@@ -534,7 +535,7 @@ $sth->execute() or warn $m_dbh->errstr;
 =cut
 
 sub quote {
-    my ( $self, @p ) = getSelf(@_);
+    my ($self, @p) = getSelf(@_);
     my $sql = $p[0];
     return $m_dbh->quote($sql);
 }
@@ -546,12 +547,11 @@ sub quote {
 =cut
 
 sub quote_identifier {
-    my ( $self, @p ) = getSelf(@_);
+    my ($self, @p) = getSelf(@_);
     my $sql = $p[0];
     return $m_dbh->quote_identifier($sql);
 }
 
-
 =head2 selectTable
 
 set a placeholder wihich is usesd by dynmaic statements.
@@ -563,8 +563,8 @@ default : querys;
 =cut
 
 sub selectTable {
-    my ( $self, @p ) = getSelf(@_);
-    $m_tbl = $m_dbh->quote_identifier( $p[0] );
+    my ($self, @p) = getSelf(@_);
+    $m_tbl = $m_dbh->quote_identifier($p[0]);
 }
 
 =head1 Privat
@@ -574,7 +574,7 @@ sub selectTable {
 =cut
 
 sub updateModules {
-    my ( $self, @p ) = getSelf(@_);
+    my ($self, @p) = getSelf(@_);
     my @q = $self->fetch_array('select title from querys');
     $m_hFunctions{$_} = $_ foreach (@q);
 }
@@ -585,14 +585,13 @@ sub updateModules {
 
 sub getSelf {
     return @_
-        if defined( $_[0] )
-            && ( !ref( $_[0] ) )
-            && ( $_[0] eq 'DBI::Library' );
+      if defined($_[0])
+      && (!ref($_[0]))
+      && ($_[0] eq 'DBI::Library');
     return (
-        defined( $_[0] )
-            && ( ref( $_[0] ) eq 'DBI::Library'
-            || UNIVERSAL::isa( $_[0], 'DBI::Library' ) )
-    ) ? @_ : ( $DBI::Library::m_sDefaultClass->new, @_ );
+            defined($_[0]) && (ref($_[0]) eq 'DBI::Library'
+                               || UNIVERSAL::isa($_[0], 'DBI::Library'))
+           ) ? @_ : ($DBI::Library::m_sDefaultClass->new, @_);
 }
 
 =head2 AUTOLOAD()
@@ -604,14 +603,14 @@ $database->showTables()
 =cut
 
 sub AUTOLOAD {
-    my ( $self, @p ) = getSelf(@_);
+    my ($self, @p) = getSelf(@_);
     our $AUTOLOAD;
-    if( $AUTOLOAD =~ /.*::(\w+)$/ and grep $1 eq $_, %m_hFunctions ) {
+    if ($AUTOLOAD =~ /.*::(\w+)$/ and grep $1 eq $_, %m_hFunctions) {
         my $attr = $1;
         {
             no strict 'refs';
             *{$AUTOLOAD} = sub {
-                $self->useexecute( $attr, @p );
+                $self->useexecute($attr, @p);
             };
         }
         goto &{$AUTOLOAD};
@@ -628,7 +627,7 @@ use vars qw(@ISA);
 =cut
 
 sub prepare {
-    my ( $m_dbh, @args ) = @_;
+    my ($m_dbh, @args) = @_;
     my $sth = $m_dbh->SUPER::prepare(@args) or return;
     return $sth;
 }
@@ -643,7 +642,7 @@ use vars qw(@ISA);
 =cut
 
 sub execute {
-    my ( $sth, @args ) = @_;
+    my ($sth, @args) = @_;
     my $rv;
     eval('$rv = $sth->SUPER::execute(@args)');
     return "$@" if $@;
@@ -656,16 +655,17 @@ sub execute {
 =cut
 
 sub fetch {
-    my ( $sth, @args ) = @_;
+    my ($sth, @args) = @_;
 
     my $row;
     eval('$row = $sth->SUPER::fetch(@args)');
     return "$@" if $@;
     if ($row) {
-    utf8::encode($row->[1])  if(utf8::is_utf8($row->[1]));
+        utf8::encode($row->[1]) if (utf8::is_utf8($row->[1]));
     }
     return $row;
 }
+
 =head1 SEE ALSO
 
 L<MySQL::Admin::GUI> L<DBI> L<DBI::Library::Database>
