@@ -1,14 +1,15 @@
 package MySQL::Admin::Actions;
 use strict;
 use warnings;
+use utf8;
 require Exporter;
 use vars qw($m_hrActions $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Actions::EXPORT = qw(loadActions saveActions $m_hrActions);
 use MySQL::Admin::Config;
 @MySQL::Admin::Actions::ISA     = qw( Exporter MySQL::Admin::Config);
-$MySQL::Admin::Actions::VERSION = '0.92';
-$DefaultClass                   = 'MySQL::Admin::Actions' unless defined $MySQL::Admin::Actions::DefaultClass;
-$defaultconfig                  = 'cgi-bin//config/actions.pl';
+$MySQL::Admin::Actions::VERSION = '0.93';
+$DefaultClass  = 'MySQL::Admin::Actions' unless defined $MySQL::Admin::Actions::DefaultClass;
+$defaultconfig = '%CONFIG%';
 
 =head1 NAME
 
@@ -52,8 +53,7 @@ loadActions() saveActions() $m_hrActions
 
 =cut
 
-sub new
-{
+sub new {
     my ($class, @initializer) = @_;
     my $self = {};
     bless $self, ref $class || $class || $DefaultClass;
@@ -64,19 +64,17 @@ sub new
 
 =cut
 
-sub loadActions
-{
+sub loadActions {
     my ($self, @p) = getSelf(@_);
     my $do = (defined $p[0]) ? $p[0] : $defaultconfig;
-    if (-e $do) {do $do;}
+    if (-e $do) { do $do; }
 }
 
 =head2 saveActions
 
 =cut
 
-sub saveActions
-{
+sub saveActions {
     my ($self, @p) = getSelf(@_);
     $self->SUPER::saveConfig(@p, $m_hrActions, 'actions');
 }
@@ -87,10 +85,11 @@ sub saveActions
 
 =cut
 
-sub getSelf
-{
+sub getSelf {
     return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'MySQL::Admin::Actions');
-    return (defined($_[0]) && (ref($_[0]) eq 'MySQL::Admin::Actions' || UNIVERSAL::isa($_[0], 'MySQL::Admin::Actions')))
+    return (defined($_[0])
+              && (ref($_[0]) eq 'MySQL::Admin::Actions'
+                  || UNIVERSAL::isa($_[0], 'MySQL::Admin::Actions')))
       ? @_
       : ($MySQL::Admin::Actions::DefaultClass->new, @_);
 }
