@@ -2,12 +2,13 @@ package MySQL::Admin::Config;
 use strict;
 use warnings;
 require Exporter;
+use utf8;
 use vars qw($config $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Config::EXPORT  = qw(loadConfig saveConfig $config);
 @ISA                           = qw(Exporter);
-$MySQL::Admin::Config::VERSION = '0.92';
-$DefaultClass                  = 'MySQL::Admin::Config' unless defined $MySQL::Admin::Config::DefaultClass;
-$defaultconfig                 = '%PATH%/config/config.pl';
+$MySQL::Admin::Config::VERSION = '0.93';
+$DefaultClass  = 'MySQL::Admin::Config' unless defined $MySQL::Admin::Config::DefaultClass;
+$defaultconfig = '%CONFIG%';
 
 =head1 NAME
 
@@ -27,8 +28,7 @@ loadConfig() saveConfig() $config
 
 =cut
 
-sub new
-{
+sub new {
     my ($class, @initializer) = @_;
     my $self = {};
     bless $self, ref $class || $class || $DefaultClass;
@@ -39,19 +39,17 @@ sub new
 
 =cut
 
-sub loadConfig
-{
+sub loadConfig {
     my ($self, @p) = getSelf(@_);
     my $do = (defined $p[0]) ? $p[0] : $defaultconfig;
-    if (-e $do) {do $do;}
+    if (-e $do) { do $do; }
 }
 
 =head2 saveConfig()
 
 =cut
 
-sub saveConfig
-{
+sub saveConfig {
     my ($self, @p) = getSelf(@_);
     my $saveAs = defined $p[0] ? $p[0] : $defaultconfig;
     $config = defined $p[1] ? $p[1] : $config;
@@ -65,7 +63,10 @@ sub saveConfig
     my $rsas = $saveAs =~ /^(\S+)$/ ? $1 : 0;
 
     if ($rsas) {
-        open $fh, ">$rsas.bak" or warn "$/MySQL::Admin::Config::saveConfig$/ $! $/ File: $rsas $/Caller: " . caller() . $/;
+        open $fh, ">$rsas.bak"
+          or warn "$/MySQL::Admin::Config::saveConfig$/ $! $/ File: $rsas $/Caller: "
+          . caller()
+          . $/;
         flock $fh, 2;
         seek $fh, 0, 0;
         truncate $fh, 0;
@@ -73,7 +74,10 @@ sub saveConfig
         close $fh;
     }
     if (-e "$rsas.bak") {
-        rename "$rsas.bak", $rsas or warn "$/MySQL::Admin::Config::saveConfig$/ $! $/ File: $rsas $/Caller: " . caller() . $/;
+        rename "$rsas.bak", $rsas
+          or warn "$/MySQL::Admin::Config::saveConfig$/ $! $/ File: $rsas $/Caller: "
+          . caller()
+          . $/;
         do $rsas;
     }
 }
@@ -86,10 +90,11 @@ see L<HTML::Menu::TreeView>
 
 =cut
 
-sub getSelf
-{
+sub getSelf {
     return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'MySQL::Admin::Config');
-    return (defined($_[0]) && (ref($_[0]) eq 'MySQL::Admin::Config' || UNIVERSAL::isa($_[0], 'MySQL::Admin::Config')))
+    return (defined($_[0])
+          && (ref($_[0]) eq 'MySQL::Admin::Config' || UNIVERSAL::isa($_[0], 'MySQL::Admin::Config'))
+      )
       ? @_
       : ($MySQL::Admin::Config::DefaultClass->new, @_);
 }
@@ -104,7 +109,7 @@ Dirk Lindner <lze@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2005-2008 by Hr. Dirk Lindner
+Copyright (C) 2005-2015 by Hr. Dirk Lindner
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public License
