@@ -1,14 +1,15 @@
 package MySQL::Admin::Session;
 use strict;
 use warnings;
+use utf8;
 require Exporter;
 use vars qw( $session $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Session::EXPORT = qw(loadSession saveSession $session);
 use MySQL::Admin::Config;
 @MySQL::Admin::Session::ISA     = qw(Exporter MySQL::Admin::Config);
-$MySQL::Admin::Session::VERSION = '0.92';
-$DefaultClass                   = 'MySQL::Admin::Session' unless defined $MySQL::Admin::Session::DefaultClass;
-$defaultconfig                  = '%PATH%/config/session.pl';
+$MySQL::Admin::Session::VERSION = '0.93';
+$DefaultClass  = 'MySQL::Admin::Session' unless defined $MySQL::Admin::Session::DefaultClass;
+$defaultconfig = '%CONFIG%';
 
 =head1 NAME
 
@@ -32,8 +33,7 @@ loadConfig() saveSession() $session
 
 =cut
 
-sub new
-{
+sub new {
     my ($class, @initializer) = @_;
     my $self = {};
     bless $self, ref $class || $class || $DefaultClass;
@@ -44,19 +44,17 @@ sub new
 
 =cut
 
-sub loadSession
-{
+sub loadSession {
     my ($self, @p) = getSelf(@_);
     my $do = (defined $p[0]) ? $p[0] : $defaultconfig;
-    if (-e $do) {do $do;}
+    if (-e $do) { do $do; }
 }
 
 =head2 saveSession
 
 =cut
 
-sub saveSession
-{
+sub saveSession {
     my ($self, @p) = getSelf(@_);
     my $l = defined $p[0] ? $p[0] : $defaultconfig;
     $self->SUPER::saveConfig($l, $session, 'session');
@@ -68,17 +66,18 @@ sub saveSession
 
 =cut
 
-sub getSelf
-{
+sub getSelf {
     return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'MySQL::Admin::Session');
-    return (defined($_[0]) && (ref($_[0]) eq 'MySQL::Admin::Session' || UNIVERSAL::isa($_[0], 'MySQL::Admin::Session')))
+    return (defined($_[0])
+              && (ref($_[0]) eq 'MySQL::Admin::Session'
+                  || UNIVERSAL::isa($_[0], 'MySQL::Admin::Session')))
       ? @_
       : ($MySQL::Admin::Session::DefaultClass->new, @_);
 }
 
 =head1 AUTHOR
 
-Dirk Lindner <dirk.lze@gmail.com>
+Dirk Lindner <lze@cpan.org>
 
 =head2 see Also
 
