@@ -1,14 +1,15 @@
 package MySQL::Admin::Settings;
 use strict;
 use warnings;
+use utf8;
 require Exporter;
 use vars qw($m_hrSettings $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Settings::EXPORT = qw(loadSettings saveSettings $m_hrSettings);
 use MySQL::Admin::Config;
 @ISA                             = qw(Exporter MySQL::Admin::Config);
-$MySQL::Admin::Settings::VERSION = '0.92';
-$DefaultClass                    = 'MySQL::Admin::Settings' unless defined $MySQL::Admin::Settings::DefaultClass;
-$defaultconfig                   = '%PATH%/config/settings.pl';
+$MySQL::Admin::Settings::VERSION = '0.93';
+$DefaultClass  = 'MySQL::Admin::Settings' unless defined $MySQL::Admin::Settings::DefaultClass;
+$defaultconfig = '%CONFIG%';
 
 =head1 NAME
 
@@ -45,8 +46,7 @@ loadSettings() saveSettings() $m_hrSettings
 
 =cut
 
-sub new
-{
+sub new {
     my ($class, @initializer) = @_;
     my $self = {};
     bless $self, ref $class || $class || $DefaultClass;
@@ -57,19 +57,17 @@ sub new
 
 =cut
 
-sub loadSettings
-{
+sub loadSettings {
     my ($self, @p) = getSelf(@_);
     my $do = (defined $p[0]) ? $p[0] : $defaultconfig;
-    if (-e $do) {do $do;}
+    if (-e $do) { do $do; }
 }
 
 =head2 saveSettings()
 
 =cut
 
-sub saveSettings
-{
+sub saveSettings {
     my ($self, @p) = getSelf(@_);
     my $l = defined $p[0] ? $p[0] : $defaultconfig;
     $self->SUPER::saveConfig($l, $m_hrSettings, 'm_hrSettings');
@@ -81,10 +79,13 @@ sub saveSettings
 
 =cut
 
-sub getSelf
-{
+sub getSelf {
     return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'MySQL::Admin::Settings');
-    return (defined($_[0]) && (ref($_[0]) eq 'MySQL::Admin::Settings' || UNIVERSAL::isa($_[0], 'MySQL::Admin::Settings')))
+    return (
+            defined($_[0])
+              && (ref($_[0]) eq 'MySQL::Admin::Settings'
+                  || UNIVERSAL::isa($_[0], 'MySQL::Admin::Settings'))
+           )
       ? @_
       : ($MySQL::Admin::Settings::DefaultClass->new, @_);
 }
