@@ -7,9 +7,9 @@ use vars qw($ACCEPT_LANGUAGE $lang $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Translate::EXPORT = qw(loadTranslate saveTranslate $lang);
 use MySQL::Admin::Config;
 @ISA                              = qw(Exporter MySQL::Admin::Config);
-$MySQL::Admin::Translate::VERSION = '0.92';
-$DefaultClass                     = 'MySQL::Admin::Translate' unless defined $MySQL::Admin::Translate::DefaultClass;
-$defaultconfig                    = '%PATH%/config/translate.pl';
+$MySQL::Admin::Translate::VERSION = '0.93';
+$DefaultClass  = 'MySQL::Admin::Translate' unless defined $MySQL::Admin::Translate::DefaultClass;
+$defaultconfig = '%CONFIG%';
 
 =head1 NAME
 
@@ -41,8 +41,7 @@ loadTranslate() saveTranslate() $lang
 
 =cut
 
-sub new
-{
+sub new {
     my ($class, @initializer) = @_;
     my $self = {};
     bless $self, ref $class || $class || $DefaultClass;
@@ -53,19 +52,17 @@ sub new
 
 =cut
 
-sub loadTranslate
-{
+sub loadTranslate {
     my ($self, @p) = getSelf(@_);
     my $do = (defined $p[0]) ? $p[0] : $defaultconfig;
-    if (-e $do) {do $do;}
+    if (-e $do) { do $do; }
 }
 
 =head2  saveTranslate()
 
 =cut
 
-sub saveTranslate
-{
+sub saveTranslate {
     my ($self, @p) = getSelf(@_);
     my $l = defined $p[0] ? $p[0] : $defaultconfig;
     $self->SUPER::saveConfig($l, $lang, 'lang');
@@ -77,10 +74,13 @@ sub saveTranslate
 
 =cut
 
-sub getSelf
-{
+sub getSelf {
     return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'MySQL::Admin::Translate');
-    return (defined($_[0]) && (ref($_[0]) eq 'MySQL::Admin::Translate' || UNIVERSAL::isa($_[0], 'MySQL::Admin::Translate')))
+    return (
+            defined($_[0])
+              && (ref($_[0]) eq 'MySQL::Admin::Translate'
+                  || UNIVERSAL::isa($_[0], 'MySQL::Admin::Translate'))
+           )
       ? @_
       : ($MySQL::Admin::Translate::DefaultClass->new, @_);
 }
@@ -91,7 +91,7 @@ L<MySQL::Admin> L<MySQL::GUI> L<MySQL::Admin::Actions> L<MySQL::Admin::Translate
 
 =head1 AUTHOR
 
-Dirk Lindner <dirk.lze@gmail.com>
+Dirk Lindner <lze@cpan.org>
 
 =head1 LICENSE
 
