@@ -1,20 +1,19 @@
 package Template::Quick;
 use strict;
 use utf8;
-use warnings FATAL => 'all';
-no warnings 'redefine';
+use warnings;
 use MySQL::Admin qw(init translate);
 require Exporter;
 use vars qw($defaultconfig $tmp $DefaultClass @EXPORT_OK @ISA $sStyle $bModPerl);
 @ISA                          = qw(Exporter);
 @Template::Quick::EXPORT      = qw(initTemplate appendHash Template initArray);
 %Template::Quick::EXPORT_TAGS = ('all' => [qw(initTemplate appendHash Template initArray  )]);
-$Template::Quick::VERSION     = '0.92';
+$Template::Quick::VERSION     = '0.93';
 $DefaultClass                 = 'Template::Quick' unless defined $Template::Quick::DefaultClass;
 our %tmplate;
-$sStyle      = 'mysql';
-$bModPerl   = ($ENV{MOD_PERL}) ? 1 : 0;
-$defaultconfig = 'cgi-bin//config/settings.pl';
+$sStyle        = 'mysql';
+$bModPerl      = ($ENV{MOD_PERL}) ? 1 : 0;
+$defaultconfig = '%CONFIG%';
 
 =head1 NAME
 
@@ -67,8 +66,7 @@ see SYNOPSIS
 
 =cut
 
-sub new
-{
+sub new {
     my ($class, @initializer) = @_;
     my $self = {};
     bless $self, ref $class || $class || $DefaultClass;
@@ -92,8 +90,7 @@ sub new
 
 =cut
 
-sub initTemplate
-{
+sub initTemplate {
     my ($self, @p) = getSelf(@_);
     my $hash = $p[0];
     $DefaultClass = $self;
@@ -112,7 +109,7 @@ sub initTemplate
 
     for (@lines) {
         $text .= chomp $_;
-        SWITCH: {
+      SWITCH: {
             if ($_ =~ /\[([^\/|\]|']+)\]([^\[\/\1\]]*)/) {
                 $tmplate{$1} = $2;
                 $o = $1;
@@ -135,8 +132,7 @@ see initTemplate
 
 =cut
 
-sub Template
-{
+sub Template {
     my ($self, @p) = getSelf(@_);
     return $self->initArray(@p);
 }
@@ -147,8 +143,7 @@ appendHash(\%hash);
 
 =cut
 
-sub appendHash
-{
+sub appendHash {
     my ($self, @p) = getSelf(@_);
     my $hash = $p[0];
     my $text = $tmplate{$hash->{name}};
@@ -167,12 +162,11 @@ sub appendHash
 
 =cut
 
-sub initArray
-{
+sub initArray {
     my ($self, @p) = getSelf(@_);
     my $tree = $p[0];
     $tmp = undef if (defined $tmp);
-    for (my $i = 0; $i < @$tree; $i++) {
+    for (my $i = 0 ; $i < @$tree ; $i++) {
         $tmp .= $self->appendHash(\%{@$tree[$i]});
     }
     return $tmp;
@@ -182,10 +176,10 @@ sub initArray
 
 =cut
 
-sub getSelf
-{
+sub getSelf {
     return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'Template::Quick');
-    return (defined($_[0]) && (ref($_[0]) eq 'Template::Quick' || UNIVERSAL::isa($_[0], 'Template::Quick')))
+    return (defined($_[0])
+            && (ref($_[0]) eq 'Template::Quick' || UNIVERSAL::isa($_[0], 'Template::Quick')))
       ? @_
       : ($Template::Quick::DefaultClass->new, @_);
 }
